<?php

$LANG = array(

'L_ID' 								=> 'N°',
'L_MENU'							=> 'Menu',
'L_UNKNOWN_ERROR'					=> 'Erreur inconnue',
'L_CONFIRM_DELETE'					=> 'Confirmer la suppression ?',
'L_SAVE_FILE'						=> 'Sauvegarder le fichier',
'L_SAVE_FILE_SUCCESSFULLY'			=> 'Fichier enregistré avec succès',
'L_SAVE_FILE_ERROR'					=> 'Erreur pendant l\'enregistrement du fichier',

'L_REPLY'							=> 'Répondre',
'L_REPLY_TO'						=> 'Répondre à',
'L_CANCEL'							=> 'Annuler',

'L_DELETE' 						    => 'Supprimer',
'L_DELETE_FILE' 				    => 'Supprimer fichier',
'L_DELETE_FOLDER'				    => 'Supprimer dossier',
'L_DELETE_SUCCESSFUL'				=> 'Suppression effectuée avec succès',
'L_DELETE_FILE_ERR'					=> 'Erreur pendant le suppression du fichier',
'L_RENAME_FILE_SUCCESSFUL'			=> 'Fichier renommé avec succès',
'L_RENAME_FILE_ERR'					=> 'Erreur pendant le traitement du fichier',
'L_RENAME_FILE'						=> 'Renommer fichier',

'L_THUMBNAIL'						=> 'Image d\'accroche (facultatif)',
'L_THUMBNAIL_SELECTION'				=> 'Sélectionner une image',
'L_THUMBNAIL_TITLE'					=> 'Titre de l\'image (facultatif)',
'L_THUMBNAIL_ALT'					=> 'Texte alternatif de l\'image (facultatif)',

'L_ERR_INVALID_DATE_CREATION'		=> 'Date de création invalide',
'L_ERR_INVALID_DATE_UPDATE'			=> 'Date de mise à jour invalide',

# class.plx.admin.php

'L_SAVE_SUCCESSFUL'					=> 'Enregistrement des données effectué avec succès',
'L_SAVE_ERR'						=> 'Erreur pendant l\'enregistrement des données',
'L_NO_ENTRY'						=> 'Accès interdit',
'L_ERR_USER_EMPTY'					=> 'Veuillez saisir un nom d\'utilisateur',
'L_ERR_PASSWORD_EMPTY'				=> 'Veuillez saisir un mot de passe',
'L_ERR_PASSWORD_EMPTY_CONFIRMATION'	=> 'Mauvaise confirmation ou mot de passe vide',
'L_ERR_INVALID_EMAIL'				=> 'Adresse email invalide',
'L_ERR_INVALID_SITE'				=> 'Adresse du site invalide',
'L_ERR_INVALID_ARTICLE_IDENT'		=> 'Identifiant d\'article invalide !',
'L_DEFAULT_NEW_CATEGORY_URL'		=> 'nouvelle-categorie',
'L_DEFAULT_NEW_STATIC_URL'			=> 'nouvelle-page',
'L_DEFAULT_NEW_ARTICLE_URL'			=> 'nouvel-article',
'L_ARTICLE_SAVE_SUCCESSFUL'			=> 'Article créé avec succès',
'L_ARTICLE_MODIFY_SUCCESSFUL'		=> 'Article mis à jour avec succès',
'L_ARTICLE_DELETE_SUCCESSFUL'		=> 'Suppression effectuée avec succès',
'L_ARTICLE_SAVE_ERR'				=> 'Erreur lors de la sauvegarde de l\'article',
'L_ARTICLE_DELETE_ERR'				=> 'Une erreur est survenue pendant la suppression de la l\'article',
'L_ERR_UNKNOWN_COMMENT'				=> 'Le commentaire demandé n\'existe pas ou n\'existe plus',
'L_COMMENT_SAVE_SUCCESSFUL'			=> 'Commentaire modifié avec succès',
'L_COMMENT_UPDATE_ERR'				=> 'Erreur lors de la mise à jour du commentaire',
'L_COMMENT_DELETE_SUCCESSFUL'		=> 'Suppression effectuée avec succès',
'L_COMMENT_DELETE_ERR'				=> 'Une erreur est survenue pendant la suppression',
'L_COMMENT_VALIDATE_SUCCESSFUL'		=> 'Validation effectuée avec succès',
'L_COMMENT_VALIDATE_ERR'			=> 'Une erreur est survenue pendant la validation',
'L_COMMENT_MODERATE_SUCCESSFUL'		=> 'Modération effectuée avec succès',
'L_COMMENT_MODERATE_ERR'			=> 'Une erreur est survenue lors de la modération',
'L_ERR_URL_ALREADY_EXISTS'			=> 'URL déjà utilisée. Veuillez modifier la valeur du champ \'URL\'',

# class.plx.media.php

'L_PLXMEDIAS_MEDIAS_FOLDER_ERR'		=> 'Impossible de créer le dossier médias pour l\'utilisateur connecté',
'L_PLXMEDIAS_ROOT'					=> 'racine',
'L_PLXMEDIAS_DELETE_FILES_SUCCESSFUL'=> 'Fichiers supprimés avec succès',
'L_PLXMEDIAS_DELETE_FILES_ERR'		=> 'Erreur pendant le suppression d\'un fichier',
'L_PLXMEDIAS_DELETE_FILE_SUCCESSFUL'=> 'Fichier supprimé avec succès',
'L_PLXMEDIAS_DELETE_FILE_ERR'		=> 'Erreur pendant le suppression du fichier',
'L_PLXMEDIAS_DEL_FOLDER_ERR'		=> 'Erreur pendant la suppression du dossier',
'L_PLXMEDIAS_DEL_FOLDER_SUCCESSFUL'	=> 'Dossier supprimé avec succès',
'L_PLXMEDIAS_NEW_FOLDER_ERR'		=> 'Impossible de créer le dossier',
'L_PLXMEDIAS_NEW_FOLDER_SUCCESSFUL'	=> 'Dossier créé avec succès',
'L_PLXMEDIAS_NEW_FOLDER_EXISTS'		=> 'Ce dossier existe déjà',
'L_PLXMEDIAS_WRONG_FILESIZE'		=> 'La taille d\'un fichier est supérieure à',
'L_PLXMEDIAS_WRONG_FILEFORMAT'		=> 'Le type d\'un fichier n\'est pas autorisé',
'L_PLXMEDIAS_UPLOAD_ERR'			=> 'Erreur pendant l\'envoi du fichier',
'L_PLXMEDIAS_UPLOAD_SUCCESSFUL'		=> 'Fichier envoyé avec succès',
'L_PLXMEDIAS_UPLOADS_ERR'			=> 'Erreur pendant l\'envoi d\'un fichier',
'L_PLXMEDIAS_UPLOADS_SUCCESSFUL'	=> 'Fichiers envoyés avec succès',
'L_PLXMEDIAS_MOVE_FILES_SUCCESSFUL'	=> 'Fichiers déplacés avec succès',
'L_PLXMEDIAS_MOVE_FILE_SUCCESSFUL'	=> 'Fichier déplacé avec succès',
'L_PLXMEDIAS_MOVE_FILES_ERR'		=> 'Erreur pendant le déplacement des fichiers',
'L_PLXMEDIAS_MOVE_FILE_ERR'			=> 'Erreur pendant le déplacement du fichier',
'L_PLXMEDIAS_MOVE_FOLDER'			=> 'Déplacer',
'L_PLXMEDIAS_RECREATE_THUMB_ERR'	=> 'Erreur pendant la création de la vignette',
'L_PLXMEDIAS_RECREATE_THUMBS_ERR'	=> 'Erreur pendant la création des vignettes',
'L_PLXMEDIAS_RECREATE_THUMB_SUCCESSFUL'	=> 'Vignette créée avec succès',
'L_PLXMEDIAS_RECREATE_THUMBS_SUCCESSFUL'=> 'Vignettes créées avec succès',

# article.php

'L_DEFAULT_NEW_ARTICLE_TITLE'		=> 'Nouvel article',
'L_ERR_INVALID_PUBLISHING_DATE'		=> 'Date de publication invalide',
'L_ERR_UNKNOWN_ARTICLE'				=> 'L\'article demandé n\'existe pas ou n\'existe plus !',
'L_ERR_FORBIDDEN_ARTICLE'			=> 'Vous n\'avez pas les droits pour accéder à cet article !',
'L_BACK_TO_ARTICLES'				=> 'Retour à la liste des articles',
'L_ARTICLE_EDITING'					=> 'Modification d\'un article',
'L_ARTICLE_TITLE'					=> 'Titre',
'L_ARTICLE_LIST_AUTHORS'			=> 'Auteur',
'L_HEADLINE_FIELD'					=> 'Chapô (facultatif)',
'L_CONTENT_FIELD'					=> 'Contenu',
'L_LINK_FIELD'						=> 'Lien de l\'article',
'L_LINK_ACCESS'						=> 'Accéder à l\'article',
'L_LINK_VIEW'						=> 'voir',
'L_ARTICLE_STATUS'					=> 'État',
'L_DRAFT' 							=> 'Brouillon',
'L_PUBLISHED' 						=> 'Publié',
'L_AWAITING'						=> 'En attente de validation',
'L_ARTICLE_DATE' 					=> 'Date de publication',
'L_NOW'								=> 'maintenant',
'L_ARTICLE_CATEGORIES' 				=> 'Emplacements',
'L_CATEGORY_HOME_PAGE' 			 	=> 'Page d\'accueil',
'L_NEW_CATEGORY' 			 		=> 'Nouvelle catégorie',
'L_ARTICLE_TAGS_FIELD' 				=> 'Mots clés',
'L_ARTICLE_TAGS_FIELD_TITLE' 		=> 'Séparer les mots clés par une virgule',
'L_ARTICLE_TOGGLER_TITLE' 			=> 'Liste des mots clés',
'L_NO_TAG' 							=> 'Aucun tag',
'L_ALLOW_COMMENTS' 					=> 'Autoriser les commentaires',
'L_ARTICLE_URL_FIELD' 				=> 'URL',
'L_ARTICLE_URL_FIELD_TITLE' 		=> 'l\'URL se remplit automatiquement à la création',
'L_ARTICLE_TEMPLATE_FIELD' 			=> 'Template',
'L_ARTICLE_MANAGE_COMMENTS'			=> 'Gérer les commentaires',
'L_ARTICLE_MANAGE_COMMENTS_TITLE'	=> 'Gérer les commentaires de cet article',
'L_ARTICLE_NEW_COMMENT'				=> 'Rédiger un commentaire',
'L_ARTICLE_NEW_COMMENT_TITLE'		=> 'Rédiger un commentaire sur cet article',
'L_ARTICLE_DELETE_CONFIRM'			=> 'Supprimer cet article ?',
'L_ARTICLE_PREVIEW_BUTTON'			=> 'Aperçu',
'L_ARTICLE_DRAFT_BUTTON' 			=> 'Enregistrer brouillon',
'L_ARTICLE_PUBLISHING_BUTTON'		=> 'Publier',
'L_ARTICLE_MODERATE_BUTTON'			=> 'Soumettre pour validation',
'L_ARTICLE_OFFLINE_BUTTON'			=> 'Mettre hors ligne',
'L_ARTICLE_UPDATE_BUTTON' 			=> 'Enregistrer',
'L_CATEGORY_ADD_BUTTON'				=> "Ajouter",
'L_ARTICLE_META_DESCRIPTION'		=> 'Contenu balise meta "description" (option)',
'L_ARTICLE_META_KEYWORDS'			=> 'Contenu balise meta "keywords" (option)',
'L_ARTICLE_TITLE_HTMLTAG'			=> 'Contenu balise title (option)',
'L_ARTICLE_CHAPO_HIDE'				=> 'masquer',
'L_ARTICLE_CHAPO_DISPLAY'			=> 'afficher',
'L_ARTICLE'							=> 'article',
'L_ARTICLE_ID'						=> 'Identifiant',

# auth.php

'L_AUTH_PAGE_TITLE'					=> 'Page d\'authentification',
'L_LOGOUT_SUCCESSFUL'				=> 'Vous avez correctement été déconnecté',
'L_LOGIN_PAGE'						=> 'Connexion à la zone d\'administration',
'L_AUTH_LOGIN_FIELD'				=> 'Login de connexion',
'L_AUTH_PASSWORD_FIELD'				=> 'Mot de passe',
'L_SUBMIT_BUTTON'					=> 'Valider',
'L_ERR_WRONG_PASSWORD' 				=> 'Login et/ou mot de passe incorrect',
'L_POWERED_BY'						=> 'Généré par <a href="http://www.pluxml.org">PluXml</a>',
'L_ERR_MAXLOGIN'					=> 'Nombre de tentative atteint<br />Réessayez dans %s minutes',

#

'L_SORT_ASCENDING_DATE'				=> 'date croissante',
'L_SORT_DESCENDING_DATE'			=> 'date décroissante',
'L_SORT_ALPHABETICAL'				=> 'alphabétique',
'L_SORT_RANDOM'						=> 'aléatoire',
'L_YES' 							=> 'Oui',
'L_NO' 								=> 'Non',
'L_OK'								=> 'Ok',
'L_NONE1'							=> 'aucun',
'L_NONE2'							=> 'aucune',

# categories.php

'L_CAT_TITLE'						=> 'Création et édition des catégories',
'L_CAT_LIST_ID' 					=> 'Identifiant',
'L_CAT_LIST_ACTIVE'					=> 'Active',
'L_CAT_LIST_NAME' 					=> 'Nom de la catégorie',
'L_CAT_LIST_URL' 					=> 'URL',
'L_CAT_LIST_SORT' 					=> 'Tri des articles',
'L_CAT_LIST_BYPAGE'					=> 'Nb art/page',
'L_CAT_LIST_ORDER' 					=> 'Ordre',
'L_CAT_LIST_MENU' 					=> 'Menu',
'L_CATEGORY'						=> 'Catégorie',
'L_DISPLAY'							=> 'Afficher',
'L_HIDE'							=> 'Masquer',
'L_OPTIONS'							=> 'Options',
'L_NEW_CATEGORY' 					=> 'Nouvelle catégorie',
'L_FOR_SELECTION' 					=> 'Pour la sélection...',
'L_CAT_APPLY_BUTTON'				=> 'Modifier la liste des catégories',
'L_CAT_UNKNOWN'						=> 'catégorie inconnue',

# categorie.php

'L_EDITCAT_PAGE_TITLE'				=> 'Édition des options de la catégorie',
'L_EDITCAT_DESCRIPTION'				=> 'Description',
'L_EDITCAT_DISPLAY_HOMEPAGE'		=> 'Afficher les articles de cette catégorie sur la page d\'accueil',
'L_EDITCAT_TEMPLATE'				=> 'Template',
'L_EDITCAT_BACK_TO_PAGE'			=> 'Retour à la liste des catégories',
'L_EDITCAT_UPDATE'					=> 'Mettre à jour cette catégorie',
'L_EDITCAT_TITLE_HTMLTAG'			=> 'Contenu balise title (option)',
'L_EDITCAT_META_DESCRIPTION'		=> 'Contenu de la balise meta "description" pour cette catégorie (option)',
'L_EDITCAT_META_KEYWORDS'			=> 'Contenu de la balise meta "keywords" pour cette catégorie (option)',

# commentaire.php

'L_COMMENT_ORPHAN' 					=> 'aucun article',
'L_COMMENT_ORPHAN_STATUS' 			=> 'non visible (nous vous conseillons de supprimer ce commentaire)',
'L_COMMENT_ARTICLE_LINKED'			=> 'Article',
'L_COMMENT_ARTICLE_LINKED_TITLE'	=> 'Article attaché à ce commentaire',
'L_COMMENT_OFFLINE' 				=> 'Hors ligne',
'L_COMMENT_ONLINE'					=> 'En ligne',
'L_COMMENT_ONLINE_TITLE'			=> 'Visualiser ce commentaire en ligne',
'L_BACK_TO_ARTICLE_COMMENTS'		=> 'Retour à la liste des commentaires de cet article',
'L_BACK_TO_COMMENTS'        		=> 'Retour à la liste des commentaires',
'L_COMMENT_EDITING' 				=> 'Édition d\'un commentaire',
'L_COMMENT_AUTHOR_FIELD'			=> 'Auteur',
'L_COMMENT_TYPE_FIELD'				=> 'Type de commentaire',
'L_COMMENT_DATE_FIELD'				=> 'Date et heure de publication',
'L_COMMENT_IP_FIELD'				=> 'IP',
'L_COMMENT_SITE_FIELD'				=> 'Site',
'L_COMMENT_EMAIL_FIELD'				=> 'E-mail',
'L_COMMENT_STATUS_FIELD'			=> 'Statut',
'L_COMMENT_LINKED_ARTICLE_FIELD'	=> 'Article attaché',
'L_COMMENT_ARTICLE_FIELD'			=> 'Commentaire',
'L_COMMENT_DELETE_CONFIRM'			=> 'Supprimer ce commentaire ?',
'L_COMMENT_PUBLISH_BUTTON'			=> 'Valider la publication',
'L_COMMENT_OFFLINE_BUTTON'			=> 'Mettre hors ligne',
'L_COMMENT_ANSWER_BUTTON'			=> 'Répondre à ce commentaire',
'L_COMMENT_UPDATE_BUTTON'			=> 'Mettre à jour',
'L_COMMENT_WRITTEN_BY'				=> 'Rédigé par',
'L_ERR_CATEGORY_ALREADY_EXISTS'		=> 'Nom de catégorie déjà utilisé',

# sous_navigation/commentaires.php

'L_COMMENT_NEW_COMMENT_TITLE'		=> 'Rédiger un nouveau commentaire pour cet article',
'L_COMMENT_NEW_COMMENT'				=> 'Rédiger un nouveau commentaire',

# commentaire_new.php

'L_ERR_ANSWER_UNKNOWN_COMMENT'		=> 'Le commentaire auquel vous tentez de répondre n\'existe pas ou n\'existe plus !',
'L_ERR_ANSWER_OFFLINE_COMMENT'		=> 'Le commentaire est hors ligne, impossible d\'y répondre !',
'L_ERR_COMMENT_UNKNOWN_ARTICLE'		=> 'L\'article demandé n\'existe pas ou n\'existe plus, impossible d\'écrire un commentaire !',
'L_ERR_CREATING_COMMENT'			=> 'Une erreur est survenue au cours de la création du commentaire',
'L_CREATING_COMMENT_SUCCESSFUL'		=> 'Le commentaire a été crée avec succès',
'L_CREATE_NEW_COMMENT'				=> 'Rédiger un commentaire',
'L_COMMENT_SAVE_BUTTON' 			=> 'Enregistrer',
'L_ARTICLE_COMMENTS_LIST'			=> 'Commentaires de cet article',
'L_COMMENT_ANSWER_TITLE' 			=> 'Répondre à ce commentaire',
'L_COMMENT_ANSWER'					=> 'Répondre',

# comments.php

'L_COMMENTS_ARTICLE_SCOPE' 			=> 'Article',
'L_COMMENTS_GLOBAL_SCOPE'			=> 'site entier',
'L_COMMENTS_LIST_DATE'				=> 'Date',
'L_COMMENTS_LIST_AUTHOR'			=> 'Auteur',
'L_COMMENTS_LIST_MESSAGE'			=> 'Message',
'L_COMMENTS_LIST_ACTION'			=> 'Action',
'L_COMMENT_EDIT'					=> 'Éditer',
'L_COMMENT_EDIT_TITLE'				=> 'Éditer ce commentaire',
'L_COMMENT_DELETE'					=> 'Supprimer',
'L_COMMENT_OFFLINE_FEEDS_TITLE'		=> 'Flux RSS des commentaires hors-ligne',
'L_COMMENT_OFFLINE_FEEDS'			=> 'Commentaires hors-ligne',
'L_COMMENT_ONLINE_FEEDS_TITLE'		=> 'Flux RSS des commentaires en-ligne',
'L_COMMENT_ONLINE_FEEDS'			=> 'Commentaires en-ligne',
'L_COMMENTS_PRIVATE_FEEDS'		    => 'Flux de syndication privés',
'L_COMMENTS_ONLINE_LIST'			=> 'Liste des commentaires publiés',
'L_COMMENTS_OFFLINE_LIST'			=> 'Liste des commentaires en attente de validation',
'L_COMMENTS_ALL_LIST'				=> 'Liste des commentaires',
'L_COMMENT_SET_ONLINE'				=> 'Mettre en ligne',
'L_COMMENT_SET_OFFLINE'				=> 'Mettre hors ligne',

# index.php

'L_SEARCH'							=> 'Rechercher',
'L_SEARCH_PLACEHOLDER'				=> 'Identifiant ou titre',
'L_ARTICLES_ALL_CATEGORIES'			=> 'Toutes les catégories...',
'L_ALL'								=> 'Tous',
'L_ALL_PUBLISHED'					=> 'Publiés',
'L_ALL_DRAFTS'						=> 'Brouillons',
'L_ALL_AWAITING_MODERATION'			=> 'En attente de validation',
'L_ARTICLES_FILTER_BUTTON'			=> 'Filtrer',
'L_CATEGORIES_TABLE'				=> 'Catégories',
'L_SPECIFIC_CATEGORIES_TABLE'		=> 'Emplacements spécifiques',
'L_ALL_ARTICLES_CATEGORIES_TABLE'	=> 'Tous les articles',
'L_ARTICLES_LIST'					=> 'Liste des articles',
'L_ARTICLE_LIST_DATE'				=> 'Date',
'L_ARTICLE_LIST_TITLE'				=> 'Titre',
'L_ARTICLE_LIST_CATEGORIES'			=> 'Catégorie',
'L_ARTICLE_LIST_NBCOMS'				=> 'Nb coms',
'L_ARTICLE_LIST_AUTHOR'				=> 'Auteur',
'L_ARTICLE_LIST_ACTION'				=> 'Action',
'L_CATEGORY_HOME'					=> 'Page d\'accueil',
'L_CATEGORY_DRAFT'					=> 'Brouillon',
'L_ARTICLE_VIEW_TITLE'				=> 'Visualiser cet article sur le site',
'L_ARTICLE_EDIT'					=> 'Éditer',
'L_ARTICLE_EDIT_TITLE'				=> 'Éditer cet article',
'L_NEW_COMMENTS_TITLE' 				=> 'Commentaires en attente de validation',
'L_VALIDATED_COMMENTS_TITLE' 		=> 'Commentaires publiés',
'L_NO_ARTICLE'						=> 'Aucun article',

# medias.php

'L_MEDIAS_FILENAME'					=> 'Nom du fichier',
'L_MEDIAS_TITLE'					=> 'Gestion des médias',
'L_MEDIAS_DIRECTORY' 				=> 'Emplacement',
'L_MEDIAS_BACK'						=> 'Retour à la liste des médias',
'L_MEDIAS_MAX_UPOLAD_FILE'			=> 'Taille maxi par fichier',
'L_MEDIAS_MAX_POST_SIZE'			=> 'Taille maxi des données',
'L_MEDIAS_SUBMIT_FILE'				=> 'Envoyer',
'L_MEDIAS_IMAGES'					=> 'Images',
'L_MEDIAS_DOCUMENTS'				=> 'Documents',
'L_MEDIAS_ADD_FILE'					=> 'Ajouter fichiers',
'L_MEDIAS_DELETE_FOLDER'			=> 'Supprimer',
'L_MEDIAS_DELETE_FOLDER_CONFIRM'	=> 'Supprimer le dossier %s et son contenu ?',
'L_MEDIAS_FOLDER'					=> 'Dossier',
'L_MEDIAS_NEW_FOLDER'				=> 'Nouveau dossier',
'L_MEDIAS_CREATE_FOLDER'			=> 'Créer',
'L_MEDIAS_FILESIZE'					=> 'Taille',
'L_MEDIAS_DATE'						=> 'Date',
'L_MEDIAS_DIMENSIONS'				=> 'Dimensions',
'L_MEDIAS_NO_FILE'					=> 'Aucun fichier',
'L_MEDIAS_RESIZE'					=> 'Redimensionner images',
'L_MEDIAS_RESIZE_NO'				=> 'Taille originale',
'L_MEDIAS_THUMBS'					=> 'Créer miniatures',
'L_MEDIAS_THUMBS_NONE'				=> 'Pas de miniature',
'L_MEDIAS_MODIFY'					=> 'Modifier',
'L_MEDIAS_THUMB'					=> 'Miniature',
'L_MEDIAS_EXTENSION'				=> 'Extension',
'L_MEDIAS_ADD'						=> 'Ajouter',
'L_MEDIAS_ALIGNMENT'				=> 'Alignement',
'L_MEDIAS_ALIGN_NONE'				=> 'Aucun',
'L_MEDIAS_ALIGN_LEFT'				=> 'Gauche',
'L_MEDIAS_ALIGN_CENTER'				=> 'Centre',
'L_MEDIAS_ALIGN_RIGHT'				=> 'Droite',
'L_MEDIAS_RECREATE_THUMB'			=> 'Recréer miniatures',
'L_MEDIAS_LINK_COPYCLP'             => 'Copier le lien dans le presse-papier',
'L_MEDIAS_LINK_COPYCLP_ERR'         => 'Impossible de copier le lien dans le presse-papier',
'L_MEDIAS_LINK_COPYCLP_DONE'        => 'Lien copié',
'L_MEDIAS_NEW_NAME'					=> 'Nouveau nom',
'L_MEDIAS_RENAME'					=> 'Renommer',

# parametres_affichage.php

'L_CONFIG_VIEW_FIELD'				=> 'Options d\'affichage',
'L_CONFIG_VIEW_SKIN_SELECT'			=> 'Choix du thème',
'L_CONFIG_VIEW_FILES_EDIT_TITLE'	=> 'Éditer les fichiers du thème',
'L_CONFIG_VIEW_FILES_EDIT'			=> 'Éditer les fichiers du thème',
'L_CONFIG_VIEW_SORT'				=> 'Tri des articles',
'L_CONFIG_VIEW_BYPAGE'				=> 'Nombre d\'articles affichés par page',
'L_CONFIG_VIEW_BYPAGE_ARCHIVES'		=> 'Nombre d\'articles affichés par page dans les archives',
'L_CONFIG_VIEW_BYPAGE_TAGS'			=> 'Nombre d\'articles affichés par page dans les mots clés',
'L_CONFIG_VIEW_BYPAGE_ADMIN'		=> 'Nombre d\'articles affichés par page dans l\'administration',
'L_CONFIG_VIEW_SORT_COMS'			=> 'Tri des commentaires',
'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'	=> 'Nombre de commentaires affichés par page dans l\'administration',
'L_CONFIG_VIEW_IMAGES'				=> 'Taille des images (largeur x hauteur)',
'L_CONFIG_VIEW_THUMBS'				=> 'Taille des miniatures (largeur x hauteur)',
'L_CONFIG_VIEW_HOMESTATIC'			=> 'Utiliser une page statique comme page d\'accueil',
'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'	=> 'Attention cette page est inactive',
'L_CONFIG_VIEW_PLUXML_RESSOURCES'	=> 'Télécharger d\'autres thèmes sur <a href="http://ressources.pluxml.org">ressources.pluxml.org</a>.',
'L_CONFIG_VIEW_BYPAGE_FEEDS'		=> 'Nombre d\'articles/commentaires affichés sur les fils RSS',
'L_CONFIG_VIEW_FEEDS_HEADLINE'		=> 'Afficher uniquement le chapô dans les flux RSS des articles',
'L_CONFIG_VIEW_FEEDS_HEADLINE_HELP'	=> 'Si le chapô est vide, le contenu est affiché',
'L_CONFIG_VIEW_FEEDS_FOOTER'		=> 'Texte à ajouter comme signature au bas de chaque flux RSS des articles',
'L_CONFIG_VIEW_UPDATE'				=> 'Modifier les options d\'affichage',
'L_CONFIG_VIEW_DISPLAY_EMPTY_CAT'	=> 'Afficher les catégories sans article',
'L_CONFIG_HOMETEMPLATE'				=> 'Template de la page d\'accueil',

# parametres_avances.php

'L_CONFIG_ADVANCED_DESC'			=> 'Configuration avancée',
'L_CONFIG_ADVANCED_URL_REWRITE'		=> 'Activer la réécriture d\'URL',
'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'=> 'Attention un fichier .htaccess est déjà présent à la racine de votre PluXml. En activant la réécriture d\'url ce fichier sera modifié',
'L_CONFIG_ADVANCED_GZIP'			=> 'Activer la compression GZIP',
'L_CONFIG_ADVANCED_GZIP_HELP'		=> 'Permet de compresser les pages pour économiser de la bande passante, cependant cela peut augmenter la charge processeur',
'L_CONFIG_ADVANCED_CAPCHA'			=> 'Activer le capcha anti-spam',
'L_CONFIG_ADVANCED_ADMIN_KEY'		=> 'Clef d\'administration (URL privés)',
'L_CONFIG_ADVANCED_KEY_HELP'		=> 'Vider ce champs pour régénérer la clef',
'L_CONFIG_ADVANCED_USERFOLDERS'		=> 'Utiliser un dossier medias différent pour chaque utilisateur',
'L_HELP_SLASH_END'					=> 'Ne pas oublier le slash à la fin',
'L_CONFIG_ADVANCED_MEDIAS_FOLDER'	=> 'Emplacement des médias (dossier)',
'L_CONFIG_ADVANCED_ARTS_FOLDER'		=> 'Emplacement des articles (dossier)',
'L_CONFIG_ADVANCED_COMS_FOLDER'		=> 'Emplacement des commentaires (dossier)',
'L_CONFIG_ADVANCED_STATS_FOLDER'	=> 'Emplacement des pages statiques (dossier)',
'L_CONFIG_ADVANCED_THEMES_FOLDER'	=> 'Emplacement des thèmes (dossier)',
'L_CONFIG_ADVANCED_PLUGINS_FOLDER'	=> 'Emplacement des plugins (dossier)',
'L_CONFIG_ADVANCED_CONFIG_FOLDER'	=> 'Emplacement des fichiers de configuration (dossier)',
'L_CONFIG_ADVANCED_UPDATE'			=> 'Modifier la configuration avancée',
'L_CONFIG_CUSTOM_CSSADMIN_PATH'		=> 'Emplacement et nom du fichier css personnel pour la personnalisation de l\'interface d\'administration (option)',

# parametres_base.php

'L_CONFIG_BASE_CONFIG_TITLE'		=> 'Configuration de base',
'L_CONFIG_BASE_SITE_TITLE'			=> 'Titre du site',
'L_CONFIG_BASE_SITE_SLOGAN'			=> 'Sous-titre/description du site',
'L_CONFIG_BASE_URL_HELP'			=> 'Ne pas oublier le slash à la fin',
'L_CONFIG_BASE_DEFAULT_LANG'		=> 'Langue par défaut du site',
'L_CONFIG_BASE_TIMEZONE'			=> 'Fuseau horaire',
'L_CONFIG_BASE_ALLOW_COMMENTS'		=> 'Autoriser les commentaires',
'L_CONFIG_BASE_MODERATE_COMMENTS'	=> 'Modérer les commentaires à la création',
'L_CONFIG_BASE_MODERATE_ARTICLES'	=> 'Modérer les articles pour les profils Rédacteur et Éditeur',
'L_CONFIG_BASE_UPDATE'				=> 'Modifier la configuration de base',
'L_CONFIG_META_DESCRIPTION'			=> 'Contenu de la balise meta "description" du site (optionnel)',
'L_CONFIG_META_KEYWORDS'			=> 'Contenu de la balise meta "keywords" du site (optionnel)',

# parametres_edittpl.php

'L_CONFIG_EDITTPL_ERROR_NOTHEME'	=> 'Ce thème n\'existe pas !',
'L_CONFIG_EDITTPL_TITLE'			=> 'Édition du thème',
'L_CONFIG_EDITTPL_SELECT_FILE'		=> 'Choix du fichier à éditer :',
'L_CONFIG_EDITTPL_LOAD'				=> 'Charger',

# parametres_infos.php

'L_CONFIG_INFOS_TITLE'				=> 'Informations relatives à PluXml',
'L_CONFIG_INFOS_DESCRIPTION'		=> 'Ces informations vous renseignent sur le fonctionnement de votre PluXml et peuvent s\'avérer utiles pour son dépannage.',
'L_CONFIG_INFOS_NB_CATS'			=> 'Nombre de catégories :',
'L_CONFIG_INFOS_NB_STATICS'			=> 'Nombre de pages statiques :',
'L_CONFIG_INFOS_WRITER'				=> 'Nom du rédacteur en session :',
'L_PLUXML_CHECK_VERSION'			=> 'Vérification du numéro de version de PluXml sur le site officiel PluXml.org',
'L_PLUXML_UPDATE_UNAVAILABLE'		=> 'Impossible de vérifier les mises à jour tant que \'allow_url_fopen\' est désactivé sur ce système',
'L_PLUXML_UPDATE_ERR'				=> 'La vérification de mise à jour a échoué pour une raison inconnue',
'L_PLUXML_UPTODATE'					=> 'Vous utilisez la dernière version de PluXml',
'L_PLUXML_UPDATE_AVAILABLE'			=> 'Une nouvelle version de PluXml est sortie ! Vous pouvez la télécharger sur',

# parametres_users.php

'L_CONFIG_USERS_TITLE'				=> 'Gestion des utilisateurs',
'L_CONFIG_USER'						=> 'utilisateur',
'L_CONFIG_USERS_ID'					=> 'Identifiant',
'L_CONFIG_USERS_ACTIVE'				=> 'Actif',
'L_CONFIG_USERS_ACTION'				=> 'Action',
'L_CONFIG_USERS_NEW'				=> 'Nouvel utilisateur',
'L_CONFIG_USERS_UPDATE'				=> 'Modifier la liste des utilisateurs',
'L_ERR_LOGIN_ALREADY_EXISTS'		=> 'Identifiant de connexion déjà utilisé',
'L_ERR_USERNAME_ALREADY_EXISTS'		=> 'Nom d\'utilisateur déjà utilisé',

# parametre_plugins.php

'L_BACK_TO_PLUGINS'					=> 'Retour à la page des plugins',
'L_NO_PLUGIN'						=> 'Aucun plugin',
'L_PLUGIN_NO_CONFIG'				=> 'Plugin non configuré',
'L_PLUGINS_CSS'						=> 'Code CSS',
'L_PLUGINS_CSS_TITLE'				=> 'Éditer le code CSS du plugin',
'L_CONTENT_FIELD_FRONTEND'			=> 'Contenu fichier CSS site',
'L_CONTENT_FIELD_BACKEND'			=> 'Contenu fichier CSS administrateur',

# parametres_plugins.php

'L_PLUGINS_TITLE'					=> 'Gestion des plugins',
'L_PLUGINS_VERSION'					=> 'Version',
'L_PLUGINS_AUTHOR'					=> 'Auteur',
'L_PLUGINS_ACTIVATE'				=> 'Activer',
'L_PLUGINS_DEACTIVATE'				=> 'Désactiver',
'L_PLUGINS_DELETE'					=> 'Supprimer',
'L_PLUGINS_DELETE_ERROR'			=> 'Une erreur s\'est produite pendant la suppression',
'L_PLUGINS_DELETE_SUCCESSFUL'		=> 'Suppression effectuée avec succès',
'L_PLUGINS_CONFIG'					=> 'Configuration',
'L_PLUGINS_CONFIG_TITLE'			=> 'Configuration du plugin',
'L_PLUGINS_HELP'					=> 'Aide',
'L_PLUGINS_HELP_TITLE'				=> 'Voir l\'aide du plugin',
'L_PLUGINS_REQUIREMENTS'			=> 'Pré-requis',
'L_PLUGINS_REQUIREMENTS_HELP'		=> 'Liste des plugins présents et actifs pour activer ce plugin',
'L_PLUGINS_REQUIREMENTS_NONE'		=> 'Aucun',
'L_PLUGINS_ALPHA_SORT'				=> 'Trier par ordre alphabétique les plugins',
'L_PLUGINS_LOADING_SORT'			=> 'Ordre de chargement',
'L_PLUGINS_ACTION'					=> 'Action',
'L_PLUGINS_APPLY_BUTTON'			=> 'Modifier la liste des plugins',
'L_PLUGINS_ACTIVE_LIST'				=> 'Plugins actifs',
'L_PLUGINS_INACTIVE_LIST'			=> 'Plugins inactifs',

# profil.php

'L_PROFIL_EDIT_TITLE'				=> 'Édition de votre profil',
'L_PROFIL'							=> 'Profil',
'L_PROFIL_LOGIN'					=> 'Identifiant de connexion',
'L_PROFIL_USER'						=> 'Nom d\'utilisateur',
'L_PROFIL_MAIL'						=> 'Adresse email',
'L_PROFIL_ADMIN_LANG'				=> 'Langue utilisée dans l\'administration',
'L_PROFIL_INFOS'					=> 'Informations',
'L_PROFIL_UPDATE'					=> 'Modifier votre profil',
'L_PROFIL_CHANGE_PASSWORD'			=> 'Changement du mot de passe',
'L_PROFIL_PASSWORD'					=> 'Mot de passe',
'L_PROFIL_CONFIRM_PASSWORD'			=> 'Confirmation du mot de passe',
'L_PROFIL_UPDATE_PASSWORD'			=> 'Changer votre mot de passe',

# statique.php

'L_STATIC_BACK_TO_PAGE'				=> 'Retour à la liste des pages statiques',
'L_STATIC_UNKNOWN_PAGE'				=> 'Cette page statique n\'existe pas ou n\'existe plus !',
'L_STATIC_TITLE'					=> 'Édition du code source de la page statique',
'L_STATIC_VIEW_PAGE'				=> 'Visualiser la page',
'L_STATIC_ON_SITE'					=> 'sur le site',
'L_STATIC_UPDATE'					=> 'Enregistrer cette page statique',
'L_STATIC_TITLE_HTMLTAG'			=> 'Contenu balise title (option)',
'L_STATIC_META_DESCRIPTION'			=> 'Contenu de la balise meta "description" pour cette page statique (option)',
'L_STATIC_META_KEYWORDS'			=> 'Contenu de la balise meta "keywords" pour cette page statique (option)',

# statiques.php

'L_STATICS_PAGE_TITLE'				=> 'Création et édition des pages statiques',
'L_STATICS_ID'						=> 'Identifiant',
'L_STATICS_GROUP'					=> 'Groupe',
'L_STATICS_TITLE'					=> 'Titre',
'L_STATICS_URL'						=> 'Url',
'L_STATICS_ACTIVE'					=> 'Active',
'L_STATICS_ORDER'					=> 'Ordre',
'L_STATICS_MENU'					=> 'Menu',
'L_STATICS_ACTION'					=> 'Action',
'L_STATICS_TEMPLATE_FIELD'			=> 'Template',
'L_STATICS_PAGE_HOME'				=> 'Définir en tant que page d\'accueil',
'L_STATICS_HOME_PAGE' 			 	=> 'Page<br />d\'accueil',
'L_PAGE'							=> 'page',
'L_VIEW'							=> 'Voir',
'L_STATICS_SRC_TITLE'				=> 'Éditer le code source de cette page',
'L_STATICS_SRC'						=> 'Éditer',
'L_STATICS_NEW_PAGE'				=> 'Nouvelle page',
'L_STATICS_UPDATE'					=> 'Modifier la liste des pages statiques',
'L_ERR_STATIC_ALREADY_EXISTS'		=> 'Titre de page statique déjà utilisé',

# top.php
'L_PROFIL_ADMIN'					=> 'Administrateur',
'L_PROFIL_MANAGER'					=> 'Gestionnaire',
'L_PROFIL_MODERATOR'				=> 'Modérateur',
'L_PROFIL_EDITOR'					=> 'Éditeur',
'L_PROFIL_WRITER'					=> 'Rédacteur',
'L_ADMIN'							=> 'Administration',
'L_LOGIN'							=> 'Connecté en tant que',
'L_ADMIN_LOGOUT'					=> 'Déconnexion',
'L_ADMIN_LOGOUT_TITLE'				=> 'Quitter la session d\'administration',
'L_BACK_TO_SITE'					=> 'Retour au site',
'L_BACK_TO_SITE_TITLE'				=> 'Retour à la page d\'accueil du site',
'L_BACK_TO_BLOG'					=> 'Blog',
'L_BACK_TO_BLOG_TITLE'				=> 'Retour à la page du blog',
'L_MENU_ARTICLES'					=> 'Articles',
'L_MENU_ARTICLES_TITLE'				=> 'Liste et modification d\'articles',
'L_MENU_NEW_ARTICLES'				=> 'Nouvel article',
'L_MENU_NEW_ARTICLES_TITLE'			=> 'Nouvel article',
'L_MENU_STATICS_TITLE'				=> 'Liste et modification des pages statiques',
'L_MENU_STATICS'					=> 'Pages statiques',
'L_MENU_COMMENTS_TITLE'				=> 'Liste et modification des commentaires',
'L_MENU_COMMENTS'					=> 'Commentaires',
'L_MENU_MEDIAS_TITLE'				=> 'Télécharger et insérer un média',
'L_MENU_MEDIAS'						=> 'Médias',
'L_MENU_CATEGORIES_TITLE'			=> 'Créer, gérer, éditer les catégories',
'L_MENU_CATEGORIES'					=> 'Catégories',
'L_MENU_CONFIG_TITLE'				=> 'Configurer PluXml',
'L_MENU_CONFIG'						=> 'Paramètres',
'L_MENU_PROFIL_TITLE'				=> 'Gérer votre profil utilisateur',
'L_MENU_PROFIL'						=> 'Profil',
'L_WARNING_INSTALLATION_FILE'		=> 'Le fichier install.php est présent à la racine de votre PluXml.<br />Pour des raisons de sécurité, il est fortement conseillé de le <a class="lnkdelete" href="?del=install">supprimer</a>.',

# user.php
'L_USER_UNKNOWN'					=> 'Utilisateur inconnu',
'L_USER_LANG'						=> 'Langue utilisée dans l\'administration',
'L_USER_MAIL'						=> 'Adresse email',
'L_USER_INFOS'						=> 'Informations',
'L_USER_UPDATE'						=> 'Mettre à jour cet utilisateur',
'L_USER_PAGE_TITLE'					=> 'Édition des options de l\'utilisateur',
'L_USER_BACK_TO_PAGE'				=> 'Retour à la liste des utilisateurs',

#

'L_MENU_CONFIG_BASE_TITLE'			=> 'Modifier la configuration de base de votre PluXml',
'L_MENU_CONFIG_BASE'				=> 'Configuration de base',
'L_MENU_CONFIG_VIEW_TITLE'			=> 'Modifier les options d\'affichage de votre PluXml',
'L_MENU_CONFIG_VIEW'				=> 'Options d\'affichage',
'L_MENU_CONFIG_USERS_TITLE'			=> 'Gérer les comptes utilisateurs de votre PluXml',
'L_MENU_CONFIG_USERS'				=> 'Comptes utilisateurs',
'L_MENU_CONFIG_ADVANCED_TITLE'		=> 'Modifier la configuration avancée de votre PluXml',
'L_MENU_CONFIG_ADVANCED'			=> 'Configuration avancée',
'L_MENU_CONFIG_INFOS_TITLE'			=> 'Avoir des informations sur votre PluXml',
'L_MENU_CONFIG_INFOS'				=> 'Informations',
'L_MENU_CONFIG_PLUGINS_TITLE'		=> 'Gérer les plugins',
'L_MENU_CONFIG_PLUGINS'				=> 'Plugins',
'L_THEMES'							=> 'Thèmes',
'L_THEMES_TITLE'					=> 'Gérer les thèmes',
'L_HELP'							=> 'Aide',
'L_HELP_TITLE'						=> 'Voir l\'aide',
'L_BACK_TO_THEMES'					=> 'Retour à la page des thèmes',
'L_CONFIG_THEME_UPDATE'				=> 'Modifier le thème',
);
?>